==> nevermined-metadata-driver-interface-0.1.5.tar.gz: nevermined-metadata-driver-interface-0.1.5/README.md <==
[![banner](https://raw.githubusercontent.com/nevermined-io/assets/main/images/logo/banner_logo.png)](https://nevermined.io)

# Metadata driver interface

> 💧 A membrane between the decentralized world and centralized world
> [nevermined.io](https://nevermined.io)

[![PyPI](https://img.shields.io/pypi/v/nevermined-metadata-driver-interface.svg)](https://pypi.org/project/nevermined-metadata-driver-interface/)
[![Python package](https://github.com/nevermined-io/metadata-driver-interface/workflows/Python%20package/badge.svg)](https://github.com/nevermined-io/metadata-driver-interface/actions)

---
## Table of Contents

- [Metadata driver interface](#metadata-driver-interface)
  - [Table of Contents](#table-of-contents)
  - [- License](#ullilicenseliul)
  - [Testing](#testing)
  - [New Version](#new-version)
  - [Attribution](#attribution)
  - [License](#license)
---
    
## Testing

Automatic tests are setup via Travis, executing `tox`.
Our tests use the pytest framework.

## New Version

The `bumpversion.sh` script helps to bump the project version. You can execute the script using {major|minor|patch} as first argument to bump the version accordingly.

## Attribution

This project is based in the Ocean Protocol [osmosis-driver-interface](https://github.com/oceanprotocol/osmosis-driver-interface).
It keeps the same Apache v2 License and adds some improvements. See [NOTICE file](NOTICE).

## License

```
Copyright 2020 Keyko GmbH
This product includes software developed at
BigchainDB GmbH and Ocean Protocol (https://www.oceanprotocol.com/)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```

==> nevermined-metadata-driver-interface-0.4.1.tar.gz: nevermined-metadata-driver-interface-0.4.1/README.md <==
[![banner](https://raw.githubusercontent.com/nevermined-io/assets/main/images/logo/banner_logo.png)](https://nevermined.io)

# Metadata driver interface

> 💧 Nevermined metadata driver interface. A membrane between the decentralized and decentralized worlds
> [nevermined.io](https://nevermined.io)

[![PyPI](https://img.shields.io/pypi/v/nevermined-metadata-driver-interface.svg)](https://pypi.org/project/nevermined-metadata-driver-interface/)
[![Python package](https://github.com/nevermined-io/metadata-driver-interface/workflows/Python%20package/badge.svg)](https://github.com/nevermined-io/metadata-driver-interface/actions)

---
## Table of Contents

- [Metadata driver interface](#metadata-driver-interface)
  - [Table of Contents](#table-of-contents)
  - [- License](#ullilicenseliul)
  - [Testing](#testing)
  - [New Version](#new-version)
  - [Attribution](#attribution)
  - [License](#license)
---
    
## Testing

Automatic tests are setup via Travis, executing `tox`.
Our tests use the pytest framework.

## New Version

The `bumpversion.sh` script helps to bump the project version. You can execute the script using {major|minor|patch} as first argument to bump the version accordingly.

## Attribution

This project is based in the Ocean Protocol [osmosis-driver-interface](https://github.com/oceanprotocol/osmosis-driver-interface).
It keeps the same Apache v2 License and adds some improvements. See [NOTICE file](NOTICE).

## License

```
Copyright 2020 Keyko GmbH
This product includes software developed at
BigchainDB GmbH and Ocean Protocol (https://www.oceanprotocol.com/)

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
```
